@@ -1,4 +1,4 @@
-# Copyright 2009-2015 Ram Rachum.
+# Copyright 2009-2017 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.address_tools.resolve`.'''
@@ -8,7 +8,7 @@ import nose.tools
 from python_toolbox.address_tools import describe, resolve
 
 
-# Class tree we'll try to some resolvings on:
+# Class tree we'll try to do some resolvings on:
 class A(object):
     def method(self):
         pass
@@ -86,20 +86,6 @@ def test_python_toolbox():
     import python_toolbox
     assert python_toolbox.caching is result
     
-    ###########################################################################
-    #                                                                         #
-    result_0 = resolve('python_toolbox.persistent.cross_process_persistent.'
-                     'CrossProcessPersistent.personality')
-    result_1 = resolve('persistent.CrossProcessPersistent.personality', 
-                       namespace=python_toolbox)
-    result_2 = resolve('persistent.CrossProcessPersistent.personality',
-                       root=python_toolbox.persistent,
-                       namespace='email') # Namespace is red herring.
-    assert result_0 is result_1 is result_2 is python_toolbox.persistent. \
-                    cross_process_persistent.CrossProcessPersistent.personality
-    #                                                                         #
-    ###########################################################################
-    
     ###########################################################################
     #                                                                         #
     result_0 = resolve('caching.cached_property.CachedProperty',
