@@ -1,4 +1,4 @@
-# Copyright 2009-2015 Ram Rachum.
+# Copyright 2009-2017 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.nifty_collections.LazyTuple`.'''
@@ -72,7 +72,7 @@ def test_empty():
     '''Test an empty `LazyTuple`.'''
     def empty_generator():
         if False: yield # (Unreachable `yield` to make this a generator.)
-        raise StopIteration
+        return
     lazy_tuple = LazyTuple(empty_generator())
     assert repr(lazy_tuple) == '<LazyTuple: (...)>'
     
