@@ -1,4 +1,4 @@
-# Copyright 2009-2015 Ram Rachum.
+# Copyright 2009-2017 Ram Rachum.
 # This program is distributed under the MIT license.
 
 from python_toolbox import string_cataloging
@@ -13,5 +13,5 @@ def test():
     assert string_cataloging.integer_to_string(y) == 'zwei'
     assert string_cataloging.integer_to_string(z) == 'drei'
     
-    assert {string_cataloging.string_to_integer('zwei') for i in xrange(10)} \
-                                                                         == {y}
\ No newline at end of file
+    assert set((string_cataloging.string_to_integer('zwei')
+                for i in xrange(10))) == set((y,))
\ No newline at end of file
