@@ -1,4 +1,4 @@
-# Copyright 2009-2015 Ram Rachum.
+# Copyright 2009-2017 Ram Rachum.
 # This program is distributed under the MIT license.
 
 import sys
@@ -7,12 +7,14 @@ import abc
 
 from python_toolbox import decorator_tools
 
-from .base_classes.decorating_context_manager import DecoratingContextManager
+from .abstract_context_manager import AbstractContextManager
+from .mixins import _DecoratingContextManagerMixin
 from .context_manager_type import ContextManagerType
 from .self_hook import SelfHook
 
 
-class ContextManager(DecoratingContextManager, metaclass=ContextManagerType):
+class ContextManager(AbstractContextManager, _DecoratingContextManagerMixin,
+                     metaclass=ContextManagerType):
     '''
     Allows running preparation code before a given suite and cleanup after.
     
