@@ -1,4 +1,4 @@
-# Copyright 2009-2015 Ram Rachum.
+# Copyright 2009-2017 Ram Rachum.
 # This program is distributed under the MIT license.
 
 '''Testing module for `python_toolbox.caching.CachedProperty`.'''
@@ -9,6 +9,11 @@ from python_toolbox import context_management
 from python_toolbox import misc_tools
 
 from python_toolbox.caching import cache, CachedType, CachedProperty
+from python_toolbox.context_management import (as_idempotent, as_reentrant,
+                                               BlankContextManager)
+
+get_depth_counting_context_manager = \
+                                    lambda: as_reentrant(BlankContextManager())
 
 
 @misc_tools.set_attributes(i=0)
@@ -180,7 +185,7 @@ def test_decorating():
     
     class A:
         reentrant_context_manager = CachedProperty(
-            lambda self: context_management.ReentrantContextManager()
+            lambda self: get_depth_counting_context_manager()
         )
         
         @reentrant_context_manager
